aboutsummaryrefslogtreecommitdiffstats
path: root/install.php
diff options
context:
space:
mode:
authorrub <rub@piwigo.org>2008-05-14 22:25:36 +0000
committerrub <rub@piwigo.org>2008-05-14 22:25:36 +0000
commit51491ab08f2be1c59439e049a20d7555ec0f918d (patch)
tree87fc14d1ba9b14beb3c908e1617ed3b8c46ce335 /install.php
parent52797d017ee3f9542ba0b6c89edf59cfeffe6215 (diff)
Change some PhpWebGallery to Piwigo.
Not all PhpWebGallery has been translated! git-svn-id: http://piwigo.org/svn/trunk@2339 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'install.php')
-rw-r--r--install.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/install.php b/install.php
index 87376ddf9..a1c737c56 100644
--- a/install.php
+++ b/install.php
@@ -142,7 +142,7 @@ if( !get_magic_quotes_gpc() )
//----------------------------------------------------- variable initialization
-define('DEFAULT_PREFIX_TABLE', 'phpwebgallery_');
+define('DEFAULT_PREFIX_TABLE', 'piwigo_');
// Obtain various vars
$dbhost = (!empty($_POST['dbhost'])) ? $_POST['dbhost'] : 'localhost';
@@ -172,10 +172,10 @@ $config_file = PHPWG_ROOT_PATH.'include/mysql.inc.php';
if (@file_exists($config_file))
{
include($config_file);
- // Is PhpWebGallery already installed ?
+ // Is Piwigo already installed ?
if (defined("PHPWG_INSTALLED"))
{
- die('PhpWebGallery is already installed');
+ die('Piwigo is already installed');
}
}
@@ -299,9 +299,9 @@ define(\'DB_COLLATE\', \'\');
// Create empty local files to avoid log errors
create_empty_local_files();
// tables creation, based on phpwebgallery_structure.sql
execute_sqlfile(
- PHPWG_ROOT_PATH.'install/phpwebgallery_structure.sql',
+ PHPWG_ROOT_PATH.'install/piwigo_structure.sql',
DEFAULT_PREFIX_TABLE,
$table_prefix
);
@@ -299,9 +299,9 @@ define(\'DB_COLLATE\', \'\');
// Create empty local files to avoid log errors
create_empty_local_files();
- // tables creation, based on phpwebgallery_structure.sql
+ // tables creation, based on piwigo_structure.sql
execute_sqlfile(